from configparser import SafeConfigParser
import sys
import os

class ConfigController():
    parser = SafeConfigParser()
    directory = 'content'
    pathPreferences = 'content/sharedPreferences.ini'

    def loadPreferences(self):
        path = self.checkSettingsFile()
        if path is not None:
            self.parser.read(path)
            return True            
        return False

    def checkSettingsFile(self):
        if os.path.exists(self.pathPreferences):
            print("os.path.exists")
            if len(self.parser.read(self.pathPreferences)) == 1:
                return self.pathPreferences
        else:
            self.createContentDir()
            self.createPreferencesFile(self.pathPreferences)
            if len(self.parser.read(self.pathPreferences)) == 1:
                return self.pathPreferences
        return None

    def createPreferencesFile(self, file):
        print("createPreferencesFile")
        createParser = SafeConfigParser()
        createParser.add_section('info')
        createParser.set('info','version', '0.1')
        createParser.add_section('settings')
        createParser.set('settings','sqlitePath', 'content/tom-db.sqlite')
        with open(file, 'w+') as iniFile:
            print('Created Preferences Inital File')
            createParser.write(iniFile)
            
    def createContentDir(self):
        print("createContentDir")
        if not os.path.exists(self.directory):
            os.makedirs(self.directory)

    def isSQLiteInstalled(self):
        try:
            sqliteVersion = self.parser.get('settings', 'sqliteVersion')
            return sqliteVersion is not None
        except:
            return False        

    def getDataBasePath(self):
        if self.loadPreferences():
            return self.parser.get('settings', 'sqlitePath')
        return None

    def setSQLiteInstalled(self):
        try:
            self.parser.set('settings', 'sqliteVersion', '3.0')
            # save to a file
            with open(self.pathPreferences, 'w') as configfile:
                self.parser.write(configfile)
            return True
        except:
            print('Error saving config')
            return False



import RPi.GPIO as GPIO
import threading
import time

statePin = 19
STATE_NOT_CONNECTED = "BLUETOOTH_NOT_CONNECTED"
STATE_CONNECTED = "BLUETOOTH_CONNECTED"
STATE_SHUTDOWN = "SHUTDOWN_IN_PROCESS"

class StateController:

    stateThread = None

    def __init__(self):
        GPIO.setup(statePin, GPIO.OUT)

    def setState(self, stateName):
        print ("Changing Thread")
        self.stop()
        print ("Create New State Thread")
        self.stateThread = StateThread(stateName)
        self.stateThread.start()

    def stop(self): 
        if self.stateThread is not None:
            print ("Kill Thread")
            self.stateThread.kill.set()
            self.stateThread.turnOff()
            self.stateThread.join()


class StateThread(threading.Thread):

    currentState = ""
    def __init__(self, state):
        threading.Thread.__init__(self)
        self.currentState = state
        self.kill = threading.Event()
    
    def run (self):
        if self.currentState == STATE_NOT_CONNECTED:
            self.blink(1)
        elif self.currentState == STATE_CONNECTED:
            self.turnOn()
        elif self.currentState == STATE_SHUTDOWN:
            self.blink(0.2)
        else: 
            self.turnOff()

    def blink(self, blinkTime):
        isOn = False
        while not self.kill.is_set():
            if isOn:
                self.turnOff()
            else:
                self.turnOn()
            isOn = not isOn
            time.sleep(blinkTime)

    def turnOff(self): 
        GPIO.output(statePin, GPIO.HIGH)

    def turnOn(self): 
        GPIO.output(statePin, GPIO.LOW)

            
